/*

    Utils

 */

.container {
    display: flex;
    justify-content: center;
    align-items: center;
}

.btn {
    display: inline-block;
    font-weight: 400;
    line-height: 1.25;
    text-align: center;
    white-space: nowrap;
    vertical-align: middle;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
    user-select: none;
    border: 1px solid transparent;
    padding: .5rem 1rem;
    font-size: 1rem;
    border-radius: .25rem;
    -webkit-transition: all .2s ease-in-out;
    -o-transition: all .2s ease-in-out;
    transition: all .2s ease-in-out;
    cursor: pointer;
}

.row {
    display: flex;
    flex-direction: row;
    justify-content: center;
}

.row .form-group {
    flex: auto;
}

/*

    Main widget

 */

.cs-container {
    position: relative;
    margin-left: auto;
    margin-right: auto;
    margin: 2rem;
}

.cs-container .cs-day {
    display: flex;
    justify-content: center;
    align-items: center;
}

.cs-container .cs-day .cs-day__name {
    width: 100%;
    min-width: 5%;
    min-height: 1px;
    display: flex;
    align-items: center;
    flex: 0 0 8%;
    cursor: default;
    text-transform: uppercase;
    font-size: 12px;

    user-select: none;
    unselectable: on;
    selectstart: false;
}

.cs-container .cs-day .cs-day__hours {
    display: flex;
}

.cs-container .cs-day .cs-day__hour {
    padding: 0.3rem 0.5rem;
    border: 1px solid #0000001f;
    cursor: pointer;
    font-weight: bold;
    user-select: none;
    unselectable: on;
    selectstart: false;
}

.cs-container .cs-day .cs-day__hour.active {
    background-color: #26a69a;
    color: white;
}

.cs-container .cs-day.cs-day__last .cs-day__hour {
    display: flex;
    flex-direction: column;
    align-items: center;

    padding: 0.4rem 0.23rem;
    font-size: 12px;
    border: 0;
    cursor: default;
}

/*

    Form

*/

.cs-form .form-group {
    margin-bottom: 1rem;
    margin-right: 20px;
}

.cs-form .form-group input, select {
    display: block;
    width: 100%;
    padding: .375rem .75rem;
    font-size: 1rem;
    line-height: 1.5;
    color: #495057;
    background-color: #fff;
    background-clip: padding-box;
    border: 1px solid #ced4da;
    border-radius: .25rem;
    transition: border-color .15s ease-in-out, box-shadow .15s ease-in-out;
    overflow: visible;
}

.cs-form .nested-forms {
    display: none;
}