# -*- coding: utf-8 -*-
# Generated by Django 1.11.1 on 2018-04-04 11:52
from __future__ import unicode_literals

import datetime
import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('c_schedules', '0002_auto_20180404_1449'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cschedulesdays',
            name='end_time',
            field=models.TimeField(validators=[django.core.validators.MinValueValidator(datetime.time(1, 0)), django.core.validators.MaxValueValidator(datetime.time(23, 59))], verbose_name='Конец'),
        ),
        migrations.AlterField(
            model_name='cschedulesdays',
            name='start_time',
            field=models.TimeField(validators=[django.core.validators.MinValueValidator(datetime.time(0, 0), django.core.validators.MaxValueValidator(datetime.time(22, 0)))], verbose_name='Старт'),
        ),
    ]
