<div class="form-group">
    {{ form.title.errors }}
    {{ form.title.label_tag }}
    {{ form.title }}
</div>

<div class="form-group row">
    <div class="form-group">
        {{ form.timezone.errors }}
        {{ form.timezone.label_tag }}
        {{ form.timezone }}
    </div>

    <div style="display: none">
        {{ form.timezone_place }}
    </div>

    <div class="form-group">
        {{ form.timezone_place.errors }}
        {{ form.timezone_place.label_tag }}
        <select id="timezone-place-select">
        </select>
    </div>
</div>


{% include 'c_schedules/shedules-area.html' %}

<div class="form-group">
    {{ form.use_work_weekend.errors }}
    {{ form.use_work_weekend.label }}
    {{ form.use_work_weekend }}
</div>
<div class="form-group">
    {{ form.use_holiday.errors }}
    {{ form.use_holiday.label }}
    {{ form.use_holiday }}
</div>

<div class="nested-forms">
    {% for form_set in inlines %}
        {{ form_set.management_form }}

        {% for form in form_set %}
            <div class="day-form">

                {{ form.day_number.errors }}
                {{ form.day_number }}

                {{ form.start_time.errors }}
                {{ form.start_time }}

                {{ form.end_time.errors }}
                {{ form.end_time }}
            </div>
        {% endfor %}
    {% endfor %}
</div>