<div class="cs-container">
    {% for day_number, day_name in days %}
        <div id="cs-day-{{ day_number }}" class="cs-day">
            <div class="cs-day__name">
                <input id="day-{{ day_number }}" type="checkbox" class="select-all-row"/>
                <span class="cs-day__value">{{ day_name }}</span>
            </div>
            <div class="cs-day__hours">
                {% for hour in hour_range %}
                    <div id="hour__{{ day_number }}_{{ hour }}" class="cs-day__hour">+</div>
                {% endfor %}
            </div>
        </div>

        {% if forloop.counter == 7 %}
            <div class="cs-day cs-day__last">
                <div class="cs-day__name"></div>
                <div class="cs-day__hours">
                    {% for hour in hour_range %}
                        <div data-hour="hour" class="cs-day__hour">

                            <span class="cs-hour__value cs-hour__start">
                                {% if forloop.counter0 < 10 %}0{{ forloop.counter0 }}{% else %}
                                    {{ forloop.counter0 }}{% endif %}
                            </span>
                            <span class="cs-hour__value cs-hour__end">
                                {% if forloop.counter0 < 10 %}0{{ forloop.counter }}{% else %}
                                    {{ forloop.counter }}{% endif %}
                            </span>
                            <input id="hour-{{ hour }}" type="checkbox" class="select-all-col"/>
                        </div>
                    {% endfor %}
                </div>
            </div>
        {% endif %}
    {% endfor %}
</div>