{% extends 'base.html' %}

{% load static %}

{% block styles %}
    {{ block.super }}
    <link rel="stylesheet" href="{% static 'c_schedules/style.css' %}"/>
{% endblock %}

{% block scripts %}
    {{ block.super }}
    <script src="{% static 'c_schedules/index.js' %}"></script>
{% endblock %}