{% extends 'c_schedules/sch_base.html' %}

{% block content %}
    <div class="container">
        <form id="cs-form" action="" method="post" class="cs-form">
            {% csrf_token %}

            {% include 'c_schedules/form_content.html' %}

            <input id="form-submit" type="submit" class="btn" value="Обновить"/>
        </form>
    </div>
{% endblock %}